@@ -6,7 +6,7 @@ use warnings;
 
 use vars qw($VERSION);
 BEGIN {
-  $VERSION='2.21'; # version template
+  $VERSION='2.22'; # version template
 }
 use Carp;
 use UNIVERSAL::DOES;
@@ -135,7 +135,7 @@ it as an argument.
 If inherited by a customized factory class, makes the invocant class
 the default factory. Every factory class should either inherit this
 method or reimplement it using a call to
-C<Treex::PML::Factory->set_default_factory>.
+C<< Treex::PML::Factory->set_default_factory >>.
 
 =item $class->new(name=>value, ...)
 
