@@ -6,7 +6,7 @@ use warnings;
 
 use vars qw($VERSION);
 BEGIN {
-  $VERSION='2.21'; # version template
+  $VERSION='2.22'; # version template
 }
 use Carp;
 
@@ -98,7 +98,7 @@ Treex::PML::Factory->createNode() instead!
 
 Create a new Treex::PML::Node object. Treex::PML::Node is basically a hash reference. This
 means that node's attributes can be accessed simply as
-C<$node->>C<{attribute}>.
+C<< $node->{attribute} >>.
 
 If a hash-reference is passed as the 1st argument, all its keys and
 values are are copied to the new Treex::PML::Node. 
