@@ -9,7 +9,7 @@ use warnings;
 
 use vars qw($VERSION);
 BEGIN {
-  $VERSION='2.21'; # version template
+  $VERSION='2.22'; # version template
 }
 no warnings 'uninitialized';
 use Scalar::Util qw( weaken );
@@ -54,7 +54,7 @@ sub schema    { return $_[0]->{-schema} }
 
 =item $decl->get_schema ()
 
-Same as C<$decl->schema()>.
+Same as C<< $decl->schema() >>.
 
 =cut
 
